@@ -22,6 +22,7 @@
 #define GEDIT_APP_PRIVATE_H
 
 #include "gedit-app.h"
+#include "gedit-metadata-manager.h"
 #include "gedit-settings.h"
 #include "gedit-menu-extension.h"
 
@@ -48,6 +49,8 @@ GtkPrintSettings	*_gedit_app_get_default_print_settings	(GeditApp         *app);
 void			 _gedit_app_set_default_print_settings	(GeditApp         *app,
 								 GtkPrintSettings *settings);
 
+GeditMetadataManager	*_gedit_app_get_metadata_manager	(GeditApp  *app);
+
 GeditSettings		*_gedit_app_get_settings		(GeditApp  *app);
 
 GMenuModel		*_gedit_app_get_hamburger_menu		(GeditApp  *app);
