@@ -31,6 +31,8 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
+#include "gedit-app.h"
+#include "gedit-app-private.h"
 #include "gedit-settings.h"
 #include "gedit-debug.h"
 #include "gedit-utils.h"
@@ -67,6 +69,8 @@ typedef struct
 	 */
 	GtkSourceSearchContext *search_context;
 
+	GeditMetadataManager *metadata_manager;
+
 	guint user_action;
 
 	guint language_set_by_user : 1;
@@ -214,6 +218,7 @@ gedit_document_dispose (GObject *object)
 	g_clear_object (&priv->editor_settings);
 	g_clear_object (&priv->metadata_info);
 	g_clear_object (&priv->search_context);
+	g_clear_object (&priv->metadata_manager);
 
 	G_OBJECT_CLASS (gedit_document_parent_class)->dispose (object);
 }
@@ -379,6 +384,15 @@ gedit_document_constructed (GObject *object)
 
 	priv = gedit_document_get_instance_private (doc);
 
+	if (!priv->use_gvfs_metadata)
+	{
+		GeditMetadataManager *metadata_manager;
+
+		metadata_manager = _gedit_app_get_metadata_manager (GEDIT_APP (g_application_get_default ()));
+		g_assert (GEDIT_IS_METADATA_MANAGER (metadata_manager));
+		priv->metadata_manager = g_object_ref (metadata_manager);
+	}
+
 	/* Bind construct properties. */
 	g_settings_bind (priv->editor_settings,
 			 GEDIT_SETTINGS_ENSURE_TRAILING_NEWLINE,
@@ -1016,23 +1030,6 @@ set_content_type (GeditDocument *doc,
 	}
 }
 
-/**
- * gedit_document_set_content_type:
- * @doc:
- * @content_type: (allow-none):
- *
- * Deprecated: 3.18: Unused function. The intent is to change the
- * #GeditDocument:content-type property to be read-only.
- */
-void
-gedit_document_set_content_type (GeditDocument *doc,
-                                 const gchar   *content_type)
-{
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-
-	set_content_type (doc, content_type);
-}
-
 /**
  * gedit_document_get_location:
  * @doc: a #GeditDocument
@@ -1058,27 +1055,6 @@ gedit_document_get_location (GeditDocument *doc)
 	return location != NULL ? g_object_ref (location) : NULL;
 }
 
-/**
- * gedit_document_set_location:
- * @doc: a #GeditDocument.
- * @location: the new location.
- *
- * Deprecated: 3.14: use gtk_source_file_set_location() instead.
- */
-void
-gedit_document_set_location (GeditDocument *doc,
-			     GFile         *location)
-{
-	GeditDocumentPrivate *priv;
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-	g_return_if_fail (G_IS_FILE (location));
-
-	priv = gedit_document_get_instance_private (doc);
-
-	gtk_source_file_set_location (priv->file, location);
-	set_content_type (doc, NULL);
-}
 
 /**
  * gedit_document_get_uri_for_display:
@@ -1202,25 +1178,6 @@ gedit_document_get_mime_type (GeditDocument *doc)
 	return g_strdup ("text/plain");
 }
 
-/**
- * gedit_document_get_readonly:
- * @doc: a #GeditDocument.
- *
- * Returns: whether the document is read-only.
- * Deprecated: 3.18: Use gtk_source_file_is_readonly() instead.
- */
-gboolean
-gedit_document_get_readonly (GeditDocument *doc)
-{
-	GeditDocumentPrivate *priv;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), TRUE);
-
-	priv = gedit_document_get_instance_private (doc);
-
-	return gtk_source_file_is_readonly (priv->file);
-}
-
 static void
 loaded_query_info_cb (GFile         *location,
 		      GAsyncResult  *result,
@@ -1623,7 +1580,7 @@ get_metadata_from_metadata_manager (GeditDocument *doc,
 
 	if (location != NULL)
 	{
-		return gedit_metadata_manager_get (location, key);
+		return gedit_metadata_manager_get (priv->metadata_manager, location, key);
 	}
 
 	return NULL;
@@ -1751,7 +1708,7 @@ gedit_document_set_metadata (GeditDocument *doc,
 		}
 		else
 		{
-			gedit_metadata_manager_set (location, key, value);
+			gedit_metadata_manager_set (priv->metadata_manager, location, key, value);
 		}
 	}
 
