@@ -19,8 +19,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GEDIT_FILE_CHOOSER_DIALOG_GTK_H__
-#define __GEDIT_FILE_CHOOSER_DIALOG_GTK_H__
+#ifndef GEDIT_FILE_CHOOSER_DIALOG_GTK_H
+#define GEDIT_FILE_CHOOSER_DIALOG_GTK_H
 
 #include <gtk/gtk.h>
 #include "gedit-file-chooser-dialog.h"
@@ -29,7 +29,7 @@ G_BEGIN_DECLS
 
 #define GEDIT_TYPE_FILE_CHOOSER_DIALOG_GTK (gedit_file_chooser_dialog_gtk_get_type ())
 
-G_DECLARE_FINAL_TYPE (GeditFileChooserDialogGtk, gedit_file_chooser_dialog_gtk, GEDIT, FILE_CHOOSER_DIALOG_GTK, GtkFileChooserDialog)
+G_DECLARE_FINAL_TYPE (GeditFileChooserDialogGtk, gedit_file_chooser_dialog_gtk, GEDIT, FILE_CHOOSER_DIALOG_GTK, GObject)
 
 GeditFileChooserDialog	*gedit_file_chooser_dialog_gtk_create		(const gchar             *title,
 									 GtkWindow               *parent,
@@ -42,6 +42,6 @@ GeditFileChooserDialog	*gedit_file_chooser_dialog_gtk_create		(const gchar
 
 G_END_DECLS
 
-#endif /* __GEDIT_FILE_CHOOSER_DIALOG_GTK_H__ */
+#endif /* GEDIT_FILE_CHOOSER_DIALOG_GTK_H */
 
 /* ex:set ts=8 noet: */
