@@ -24,6 +24,13 @@ from .outputpanel import OutputPanel
 from .capture import Capture
 from .functions import *
 
+try:
+    import gettext
+    gettext.bindtextdomain('gedit')
+    gettext.textdomain('gedit')
+    _ = gettext.gettext
+except:
+    _ = lambda s: s
 
 class ToolActions(object):
     def __init__(self, library, window, panel):
@@ -45,7 +52,8 @@ class ToolActions(object):
 
     def _insert_directory(self, directory):
         for tool in sorted(directory.tools, key=lambda x: x.name.lower()):
-            action_name = 'external-tool_%X_%X' % (id(tool), id(tool.name))
+            # FIXME: find a better way to share the action name
+            action_name = 'external-tool-%X-%X' % (id(tool), id(tool.name))
             self._action_tools[action_name] = tool
 
             action = Gio.SimpleAction(name=action_name)
