@@ -3,7 +3,7 @@
  * gedit-file-browser-message-set-emblem.c
  * This file is part of gedit
  *
- * Copyright (C) 2011 - Jesse van den Kieboom
+ * Copyright (C) 2014 - Jesse van den Kieboom
  *
  * gedit is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,8 +27,6 @@
 
 #include "gedit-file-browser-message-set-emblem.h"
 
-#define GEDIT_FILE_BROWSER_MESSAGE_SET_EMBLEM_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_FILE_BROWSER_MESSAGE_SET_EMBLEM, GeditFileBrowserMessageSetEmblemPrivate))
-
 enum
 {
 	PROP_0,
@@ -43,7 +41,11 @@ struct _GeditFileBrowserMessageSetEmblemPrivate
 	gchar *emblem;
 };
 
-G_DEFINE_TYPE (GeditFileBrowserMessageSetEmblem, gedit_file_browser_message_set_emblem, GEDIT_TYPE_MESSAGE)
+G_DEFINE_TYPE_EXTENDED (GeditFileBrowserMessageSetEmblem,
+                        gedit_file_browser_message_set_emblem,
+                        GEDIT_TYPE_MESSAGE,
+                        0,
+                        G_ADD_PRIVATE (GeditFileBrowserMessageSetEmblem))
 
 static void
 gedit_file_browser_message_set_emblem_finalize (GObject *obj)
@@ -133,12 +135,10 @@ gedit_file_browser_message_set_emblem_class_init (GeditFileBrowserMessageSetEmbl
 	                                                      G_PARAM_READWRITE |
 	                                                      G_PARAM_CONSTRUCT |
 	                                                      G_PARAM_STATIC_STRINGS));
-
-	g_type_class_add_private (object_class, sizeof (GeditFileBrowserMessageSetEmblemPrivate));
 }
 
 static void
 gedit_file_browser_message_set_emblem_init (GeditFileBrowserMessageSetEmblem *message)
 {
-	message->priv = GEDIT_FILE_BROWSER_MESSAGE_SET_EMBLEM_GET_PRIVATE (message);
+	message->priv = gedit_file_browser_message_set_emblem_get_instance_private (message);
 }
